@@ -38,9 +38,9 @@ from .datadialogs import (AddDialog, CustomizeDialog, DirectoryDialog,
                           LimitDialog, LockDialog, LogDialog,
                           ManageBackupsDialog, NewDialog, PasteDialog,
                           PlotDialog, PlotScalarDialog, PreferencesDialog,
-                          ProjectionDialog, RemoteDialog, RemovePluginDialog,
-                          RenameDialog, RestorePluginDialog, ScanDialog,
-                          SignalDialog, UnlockDialog, ViewDialog)
+                          ProjectionDialog, RemovePluginDialog, RenameDialog,
+                          RestorePluginDialog, ScanDialog, SignalDialog,
+                          UnlockDialog, ViewDialog)
 from .fitdialogs import FitDialog
 from .plotview import NXPlotView
 from .pyqt import QtCore, QtGui, QtWidgets, getOpenFileName, getSaveFileName
@@ -267,14 +267,6 @@ class MainWindow(QtWidgets.QMainWindow):
             "Open Directory...", self, triggered=self.open_directory)
         self.add_menu_action(self.file_menu, self.opendirectory_action)
 
-        try:
-            import h5pyd
-            self.openremotefile_action = QtWidgets.QAction(
-                "Open Remote...", self, triggered=self.open_remote_file)
-            self.add_menu_action(self.file_menu, self.openremotefile_action)
-        except ImportError:
-            pass
-
         self.savefile_action = QtWidgets.QAction(
             "&Save as...", self, shortcut=QtGui.QKeySequence.Save,
             triggered=self.save_file)
@@ -287,10 +279,10 @@ class MainWindow(QtWidgets.QMainWindow):
 
         self.file_menu.addSeparator()
 
-        self.restore_action = QtWidgets.QAction(
+        self.restore_session_action = QtWidgets.QAction(
             "Restore Session", self, shortcut=QtGui.QKeySequence("Ctrl+R"),
             triggered=self.restore_session)
-        self.add_menu_action(self.file_menu, self.restore_action)
+        self.add_menu_action(self.file_menu, self.restore_session_action)
 
         self.file_menu.addSeparator()
 
@@ -355,9 +347,9 @@ class MainWindow(QtWidgets.QMainWindow):
             triggered=self.backup_file)
         self.add_menu_action(self.file_menu, self.backup_action)
 
-        self.restore_action = QtWidgets.QAction("Restore Backup...", self,
-                                                triggered=self.restore_file)
-        self.add_menu_action(self.file_menu, self.restore_action)
+        self.restore_backup_action = QtWidgets.QAction(
+            "Restore Backup...", self, triggered=self.restore_file)
+        self.add_menu_action(self.file_menu, self.restore_backup_action)
 
         self.manage_backups_action = QtWidgets.QAction(
             "Manage Backups...", self, triggered=self.manage_backups)
@@ -963,14 +955,6 @@ class MainWindow(QtWidgets.QMainWindow):
         except NeXusError as error:
             report_error("Opening Directory", error)
 
-    def open_remote_file(self):
-        try:
-            dialog = RemoteDialog(parent=self)
-            dialog.setModal(False)
-            dialog.show()
-        except NeXusError as error:
-            report_error("Opening Remote File", error)
-
     def hover_recent_menu(self, action):
         position = QtGui.QCursor.pos()
         position.setX(position.x() + 80)
