@@ -314,6 +314,7 @@ class NXTreeView(QtWidgets.QTreeView):
         self.mainwindow.lockfile_action.setEnabled(False)
         self.mainwindow.unlockfile_action.setEnabled(False)
         self.mainwindow.backup_action.setEnabled(False)
+        self.mainwindow.restore_backup_action.setEnabled(False)
         self.mainwindow.plot_data_action.setEnabled(False)
         self.mainwindow.plot_line_action.setEnabled(False)
         self.mainwindow.overplot_data_action.setEnabled(False)
@@ -367,7 +368,7 @@ class NXTreeView(QtWidgets.QTreeView):
                     self.mainwindow.lockfile_action.setEnabled(True)
                 self.mainwindow.backup_action.setEnabled(True)
                 if node.nxbackup:
-                    self.mainwindow.restore_action.setEnabled(True)
+                    self.mainwindow.restore_backup_action.setEnabled(True)
             if node.nxfilemode is None or node.nxfilemode == 'rw':
                 if self.mainwindow.copied_node is not None:
                     self.mainwindow.pastedata_action.setEnabled(True)
@@ -478,6 +479,7 @@ class NXTreeView(QtWidgets.QTreeView):
         self.addMenu(self.mainwindow.duplicate_action)
         self.addMenu(self.mainwindow.export_action)
         self.addMenu(self.mainwindow.backup_action)
+        self.addMenu(self.mainwindow.restore_backup_action)
         self.menu.addSeparator()
         self.addMenu(self.mainwindow.collapse_action)
         return self.menu
@@ -498,13 +500,15 @@ class NXTreeView(QtWidgets.QTreeView):
                 if node.nxfilemode and not node.file_exists():
                     _dir = node.nxfile._filedir
                     if not os.path.exists(_dir):
-                        display_message(f"'{_dir}' no longer exists")
+                        display_message("Files removed",
+                                        f"'{_dir}' no longer exists")
                         for _key in [k for k in self.tree
                                      if self.tree[k].nxfile._filedir == _dir]:
                             del self.tree[_key]
                         break
                     else:
                         display_message(
+                            "File removed",
                             f"'{node.nxfilename}' no longer exists")
                         del self.tree[key]
                 elif node.is_modified():
